import Vue from "vue";
import VueRouter from "vue-router";
import { getToken, removeToken } from "@/utils/auth";
import { clearStore } from "@/utils/store.js";
import store from "../store";
import { validatenull } from "../utils/validate";
// import login from "../views/common/login.vue";
// import layout from "../views/module/layout.vue";
// import home from "../views/module/home/index.vue";
Vue.use(VueRouter);

// 重写路由 解决 push报错问题
const routerPush = VueRouter.prototype.push;
VueRouter.prototype.push = function push(location) {
  return routerPush.call(this, location).catch(error => error);
};
const globalRoutes = [
  {
    path: "/404",
    name: "404",
    component: import("../views/common/404.vue"),
    meta: {
      keepAlive: true,
      isAuth: false,
      title: "404未找到"
    }
  },
  {
    path: "/login",
    name: "login",
    component: () => import("@/views/common/login.vue"),
    meta: {
      keepAlive: true,
      isAuth: false,
      title: "登陆"
    }
  }
];
// 主入口路由(需嵌套上左右整体布局)
const mainRoutes = [
  {
    path: "/",
    component: () => import("@/views/module/layout.vue"),
    name: "layout",
    redirect: {
      name: "home"
    },
    meta: {
      title: "主入口整体布局"
    },
    children: [
      {
        path: "/home",
        component: () => import("@/views/module/home/index.vue"),
        name: "home",
        meta: {
          keepAlive: false,
          isAuth: true,
          title: "首页"
        }
      }
    ]
  }
];

const router = new VueRouter({
  mode: "history",
  scrollBehavior: () => ({
    y: 0
  }),
  routes: globalRoutes.concat(mainRoutes)
  // ...globalRoutes,
  // ...mainRoutes
});
/**
 * 路由守卫(拦截)
 */
router.beforeEach((to, from, next) => {
  // 缓冲设置
  if (to.meta.keepAlive === true) {
    to.meta.$keepAlive = true;
  } else {
    to.meta.$keepAlive = false;
  }

  if (getToken()) {
    if (to.path === "/login") {
      next({
        path: "/"
      });
    } else {
      // console.log(validatenull(store.state.userInfo));
      // console.log(store.state.userInfo);
      // 如果用户信息为空则获取用户信息，获取用户信息失败，跳转到登录页
      if (!validatenull(store.state.userInfo)) {
        store.dispatch("loginOut").then(() => {
          removeToken(); // 清除Token
          clearStore(); // 清除localStorage
          next({
            path: "/login"
          });
        });
      } else {
        next();
      }
    }
  } else {
    // 判断是否需要认证，没有登录访问去登录页
    if (to.meta.isAuth === false) {
      next();
    } else {
      next("/login");
    }
  }
});

export default router;
