import axios from "axios";
import router from "../router";
// import store from "../store";
// import { serialize } from "../utils/util";
import { getToken } from "./auth"; // Cookie操作
// import { Message } from "view-design";
import NProgress from "nprogress"; // 页面加载进度条

const http = axios.create({
  timeout: 1000 * 30, // 请求超时时间30秒(单位：毫秒)
  // withCredentials: true, // 跨域请求，允许保存cookie
  validateStatus: function(status) {
    return status >= 200 && status <= 500; // 默认的
  },
  headers: {
    "Content-Type": "application/x-www-form-urlencoded"
    // "X-Requested-With": "XMLHttpRequest"
  },
  device: "web"
});
const Qs = require("qs");

// NProgress Configuration
NProgress.configure({
  showSpinner: false
});

/**
 * HTTP request拦截
 */
http.interceptors.request.use(
  config => {
    NProgress.start(); // start progress bar
    // const meta = config.meta || {};
    // const isToken = meta.isToken === false;
    // if (getToken() && !isToken) {
    if (getToken()) {
      config.headers["token"] = getToken(); // 让每个请求携带token
    } else {
      router.push({ name: "login" });
    }
    // headers中配置serialize为true开启序列化
    config.data.device = "web";
    config.data = Qs.stringify(config.data);
    console.log(config);
    return config;
  },
  error => {
    return Promise.reject(error);
  }
);

/**
 * HTTP response拦截
 */
http.interceptors.response.use(
  response => {
    if (response.config.url.indexOf(".json") !== -1) {
      return response;
    } else {
      if (response.status === 200) {
        if (response.data) {
          if (response.data.code === 2) {
            if (window.vue) {
              // 如果是登录失效转跳登录页面
              window.vue.$router.push("/login");
            }
          } else if (response.data.code === 1) {
            // window.vue.$message.error(response.data.msg);
            return response.data;
          }
          return response.data;
        } else {
          return response;
        }
      } else {
        window.vue.$message.error("接口请求失败");
      }
    }
  },
  error => {
    return Promise.reject(error);
  }
);

export default http;
